@@ -1,5 +1,5 @@
+from lightwood.encoders.text.pretrained import PretrainedLang
 from lightwood.encoders.text.rnn import RnnEncoder
-from lightwood.encoders.text.distilbert import DistilBertEncoder
 from lightwood.encoders.text.tfidf import TfidfEncoder
 from lightwood.encoders.text.short import ShortTextEncoder
 from lightwood.encoders.text.vocab import VocabularyEncoder
