@@ -101,3 +101,8 @@ class BoostMixer(BaseMixer):
                 except Exception:
                     pass
         return predictions
+
+    def to(self, device, available_devices):
+        for enc_name in self.encoders:
+            self.encoders[enc_name].to(device, available_devices)
+        return self
